This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

patch correcting spelling errors in comments



This is a set of trivial spelling corrections  in
comments that was approved some weeks ago: I've been on vacation.

The justification for the dependant->dependent change
was explained then at some length and if anyone cares
I can repeat it...


2000-09-01  David Anderson  <davea@sgi.com>

	* arch-utils.c arch-utils.h blockframe.c fork-child.c:
	Corrected comment spelling dependant->dependent.
	* corelow.c (default_core_sniffer): Corrected comment 
	spelling.
	* cp-valprint.c (cp_print_value_fields): Corrected 
	comment spelling.
	* d10v-tdep.c dbxread.c: Corrected comment spelling 
	dependan->dependen.
	* defs.h: Corrected spelling, meant 64, not 32, in comment.
	* dst.h eval.c event-loop.c: Corrected comment spelling.
	* event-top.c gdb-events.sh: Corrected comment spelling.
	* gdbarch.c: Corrected comment spelling.
	* gdbarch.h gdbarch.sh: Corrected comment spelling,
	dependant->dependent.
	* gdbtypes.c gdbtypes.h: Corrected comment spelling.
	* infcmd.c infrun.c: Corrected comment spelling.
	* symfile.c symfile.h target.h: Corrected comment spelling,
	dependant->dependent.
	* tracepoint.h: Corrected comment spelling.

 
Index: arch-utils.c
===================================================================
RCS file: /cvs/src/src/gdb/arch-utils.c,v
retrieving revision 1.13
diff -u -p -r1.13 arch-utils.c
--- arch-utils.c	2000/08/11 01:30:11	1.13
+++ arch-utils.c	2000/09/01 23:20:48
@@ -541,7 +541,7 @@ info_architecture (char *args, int from_
   printf_filtered ("\n");
 }
 
-/* Set the dynamic target-system-dependant parameters (architecture,
+/* Set the dynamic target-system-dependent parameters (architecture,
    byte-order) using information found in the BFD */
 
 void
Index: blockframe.c
===================================================================
RCS file: /cvs/src/src/gdb/blockframe.c,v
retrieving revision 1.6
diff -u -p -r1.6 blockframe.c
--- blockframe.c	2000/08/09 20:09:01	1.6
+++ blockframe.c	2000/09/01 23:20:49
@@ -1037,7 +1037,7 @@ pc_in_call_dummy_at_entry_point (CORE_AD
  * The following code serves to maintain the dummy stack frames for
  * inferior function calls (ie. when gdb calls into the inferior via
  * call_function_by_hand).  This code saves the machine state before 
- * the call in host memory, so we must maintain an independant stack 
+ * the call in host memory, so we must maintain an independent stack 
  * and keep it consistant etc.  I am attempting to make this code 
  * generic enough to be used by many targets.
  *
Index: corelow.c
===================================================================
RCS file: /cvs/src/src/gdb/corelow.c,v
retrieving revision 1.8
diff -u -p -r1.8 corelow.c
--- corelow.c	2000/08/27 04:21:35	1.8
+++ corelow.c	2000/09/01 23:20:49
@@ -109,7 +109,7 @@ default_core_sniffer (struct core_fns *o
 
 /* Walk through the list of core functions to find a set that can
    handle the core file open on ABFD.  Default to the first one in the
-   list of nothing matches.  Returns pointer to set that is
+   list if nothing matches.  Returns pointer to set that is
    selected. */
 
 static struct core_fns *
Index: cp-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/cp-valprint.c,v
retrieving revision 1.4
diff -u -p -r1.4 cp-valprint.c
--- cp-valprint.c	2000/07/30 01:48:25	1.4
+++ cp-valprint.c	2000/09/01 23:20:50
@@ -458,7 +458,7 @@ cp_print_value_fields (struct type *type
 	    }			/* non-RRBC case */
 	  else
 	    {
-	      /* FIXME -- seem comments above */
+	      /* FIXME -- see comments above */
 	      /* RRBC support present; function pointers are found
 	       * by indirection through the class segment entries. */
 
Index: d10v-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/d10v-tdep.c,v
retrieving revision 1.11
diff -u -p -r1.11 d10v-tdep.c
--- d10v-tdep.c	2000/08/13 01:22:17	1.11
+++ d10v-tdep.c	2000/09/01 23:20:50
@@ -191,7 +191,7 @@ d10v_ts3_register_name (int reg_nr)
   return register_names[reg_nr];
 }
 
-/* Access the DMAP/IMAP registers in a target independant way. */
+/* Access the DMAP/IMAP registers in a target independent way. */
 
 static unsigned long
 d10v_ts2_dmap_register (int reg_nr)
Index: dbxread.c
===================================================================
RCS file: /cvs/src/src/gdb/dbxread.c,v
retrieving revision 1.8
diff -u -p -r1.8 dbxread.c
--- dbxread.c	2000/08/21 17:30:58	1.8
+++ dbxread.c	2000/09/01 23:20:51
@@ -791,12 +791,12 @@ struct cont_elem
     /* sym and stabsstring for continuing information in cfront */
     struct symbol *sym;
     char *stabs;
-    /* state dependancies (statics that must be preserved) */
+    /* state dependencies (statics that must be preserved) */
     int sym_idx;
     int sym_end;
     int symnum;
     int (*func) (struct objfile *, struct symbol *, char *);
-    /* other state dependancies include:
+    /* other state dependencies include:
        (assumption is that these will not change since process_now FIXME!!)
        stringtab_global
        n_stabs
@@ -1836,7 +1836,7 @@ read_ofile_symtab (struct partial_symtab
 
   pst->symtab = end_symtab (text_offset + text_size, objfile, SECT_OFF_TEXT (objfile));
 
-  /* Process items which we had to "process_later" due to dependancies 
+  /* Process items which we had to "process_later" due to dependencies 
      on other stabs.  */
   process_now (objfile);
 
Index: defs.h
===================================================================
RCS file: /cvs/src/src/gdb/defs.h,v
retrieving revision 1.30
diff -u -p -r1.30 defs.h
--- defs.h	2000/08/11 02:55:38	1.30
+++ defs.h	2000/09/01 23:20:52
@@ -801,10 +801,10 @@ enum val_prettyprint
 #endif
 
 #if !defined (ULONGEST_MAX)
-#define	ULONGEST_MAX (~(ULONGEST)0)        /* 0xFFFFFFFFFFFFFFFF for 32-bits */
+#define	ULONGEST_MAX (~(ULONGEST)0)        /* 0xFFFFFFFFFFFFFFFF for 64-bits */
 #endif
 
-#if !defined (LONGEST_MAX)                 /* 0x7FFFFFFFFFFFFFFF for 32-bits */
+#if !defined (LONGEST_MAX)                 /* 0x7FFFFFFFFFFFFFFF for 64-bits */
 #define	LONGEST_MAX ((LONGEST)(ULONGEST_MAX >> 1))
 #endif
 
Index: dst.h
===================================================================
RCS file: /cvs/src/src/gdb/dst.h,v
retrieving revision 1.1.1.2
diff -u -p -r1.1.1.2 dst.h
--- dst.h	1999/07/07 20:05:39	1.1.1.2
+++ dst.h	2000/09/01 23:20:52
@@ -541,7 +541,7 @@ typedef enum
   }
 dst_var_loc_t;
 
-/* Locations come in two versions. The sort, and the long. The difference
+/* Locations come in two versions. The short, and the long. The difference
  * between the short and the long is the addition of a statement number
  * field to the start andend of the range of the long, and and unkown
  * purpose field in the middle. Also, loc_type and loc_index aren't
Index: eval.c
===================================================================
RCS file: /cvs/src/src/gdb/eval.c,v
retrieving revision 1.7
diff -u -p -r1.7 eval.c
--- eval.c	2000/07/30 01:48:25	1.7
+++ eval.c	2000/09/01 23:20:53
@@ -173,7 +173,7 @@ get_label (register struct expression *e
     return NULL;
 }
 
-/* This function evaluates tupes (in Chill) or brace-initializers
+/* This function evaluates tuples (in Chill) or brace-initializers
    (in C/C++) for structure types.  */
 
 static value_ptr
Index: event-loop.c
===================================================================
RCS file: /cvs/src/src/gdb/event-loop.c,v
retrieving revision 1.7
diff -u -p -r1.7 event-loop.c
--- event-loop.c	2000/07/05 10:25:43	1.7
+++ event-loop.c	2000/09/01 23:20:53
@@ -96,7 +96,7 @@ typedef void (event_handler_func) (int);
    ready. The procedure PROC associated with each event is always the
    same (handle_file_event).  Its duty is to invoke the handler
    associated with the file descriptor whose state change generated
-   the event, plus doing other cleanups adn such. */
+   the event, plus doing other cleanups and such. */
 
 struct gdb_event
   {
@@ -248,7 +248,7 @@ static struct
   }
 sighandler_list;
 
-/* Is any of the handlers ready?  Check this variable using
+/* Are any of the handlers ready?  Check this variable using
    check_async_ready. This is used by process_event, to determine
    whether or not to invoke the invoke_async_signal_handler
    function. */
@@ -392,7 +392,7 @@ process_event (void)
    wait for something to happen (via gdb_wait_for_event), then process
    it.  Returns >0 if something was done otherwise returns <0 (this
    can happen if there are no event sources to wait for).  If an error
-   occures catch_errors() which calls this function returns zero. */
+   occurs catch_errors() which calls this function returns zero. */
 
 static int
 gdb_do_one_event (void *data)
Index: event-top.c
===================================================================
RCS file: /cvs/src/src/gdb/event-top.c,v
retrieving revision 1.8
diff -u -p -r1.8 event-top.c
--- event-top.c	2000/07/30 01:48:25	1.8
+++ event-top.c	2000/09/01 23:20:53
@@ -157,7 +157,7 @@ struct readline_input_state
 readline_input_state;
 
 
-/* Wrapper function foe calling into the readline library. The event
+/* Wrapper function for calling into the readline library. The event
    loop expects the callback function to have a paramter, while readline 
    expects none. */
 static void
@@ -515,7 +515,7 @@ command_handler (char *command)
   execute_command (command, instream == stdin);
 
   /* Set things up for this function to be compete later, once the
-     executin has completed, if we are doing an execution command,
+     execution has completed, if we are doing an execution command,
      otherwise, just go ahead and finish. */
   if (target_can_async_p () && target_executing)
     {
Index: fork-child.c
===================================================================
RCS file: /cvs/src/src/gdb/fork-child.c,v
retrieving revision 1.5
diff -u -p -r1.5 fork-child.c
--- fork-child.c	2000/08/23 16:37:23	1.5
+++ fork-child.c	2000/09/01 23:20:53
@@ -358,7 +358,7 @@ fork_inferior (char *exec_file, char *al
      correct program, and are poised at the first instruction of the
      new program.  */
 
-  /* Allow target dependant code to play with the new process.  This might be
+  /* Allow target dependent code to play with the new process.  This might be
      used to have target-specific code initialize a variable in the new process
      prior to executing the first instruction.  */
   TARGET_CREATE_INFERIOR_HOOK (pid);
Index: gdb-events.sh
===================================================================
RCS file: /cvs/src/src/gdb/gdb-events.sh,v
retrieving revision 1.3
diff -u -p -r1.3 gdb-events.sh
--- gdb-events.sh	2000/04/03 04:43:26	1.3
+++ gdb-events.sh	2000/09/01 23:20:53
@@ -34,7 +34,7 @@
 # here with respect to annotate.  We might need to accomodate a hook
 # stack that allows several ui blocks to install their own events.
 
-# Each of the variable events (as currently generated) is converteded
+# Each of the variable events (as currently generated) is converted
 # to either a straight function call or a function call with a
 # predicate.
 
Index: gdbarch.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.c,v
retrieving revision 1.41
diff -u -p -r1.41 gdbarch.c
--- gdbarch.c	2000/08/25 20:51:19	1.41
+++ gdbarch.c	2000/09/01 23:20:55
@@ -3811,7 +3811,7 @@ gdbarch_data (struct gdbarch_data *data)
 
 
 
-/* Keep a registrary of swaped data required by GDB modules. */
+/* Keep a registrary of swapped data required by GDB modules. */
 
 struct gdbarch_swap
 {
Index: gdbarch.h
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.h,v
retrieving revision 1.34
diff -u -p -r1.34 gdbarch.h
--- gdbarch.h	2000/08/25 20:51:19	1.34
+++ gdbarch.h	2000/09/01 23:20:56
@@ -77,7 +77,7 @@ extern int gdbarch_byte_order (struct gd
 #endif
 
 
-/* The following are initialized by the target dependant code. */
+/* The following are initialized by the target dependent code. */
 
 /* Number of bits in a char or unsigned char for the target machine.
    Just like CHAR_BIT in <limits.h> but describes the target machine.
@@ -1350,7 +1350,7 @@ extern struct gdbarch_tdep *gdbarch_tdep
 
    The mechanisms below ensures that there is only a loose connection
    between the set-architecture command and the various GDB
-   components.  Each component can independantly register their need
+   components.  Each component can independently register their need
    to maintain architecture specific data with gdbarch.
 
    Pragmatics:
@@ -1360,7 +1360,7 @@ extern struct gdbarch_tdep *gdbarch_tdep
 
    The more traditional mega-struct containing architecture specific
    data for all the various GDB components was also considered.  Since
-   GDB is built from a variable number of (fairly independant)
+   GDB is built from a variable number of (fairly independent)
    components it was determined that the global aproach was not
    applicable. */
 
@@ -1520,7 +1520,7 @@ extern void register_gdbarch_swap (void 
 
 
 
-/* The target-system-dependant byte order is dynamic */
+/* The target-system-dependent byte order is dynamic */
 
 /* TARGET_BYTE_ORDER_SELECTABLE_P determines if the target endianness
    is selectable at runtime.  The user can use the ``set endian''
@@ -1560,7 +1560,7 @@ extern int target_byte_order_auto;
 
 
 
-/* The target-system-dependant BFD architecture is dynamic */
+/* The target-system-dependent BFD architecture is dynamic */
 
 extern int target_architecture_auto;
 #ifndef TARGET_ARCHITECTURE_AUTO
@@ -1573,7 +1573,7 @@ extern const struct bfd_arch_info *targe
 #endif
 
 
-/* The target-system-dependant disassembler is semi-dynamic */
+/* The target-system-dependent disassembler is semi-dynamic */
 
 #include "dis-asm.h"		/* Get defs for disassemble_info */
 
@@ -1614,7 +1614,7 @@ extern disassemble_info tm_print_insn_in
 #endif
 
 
-/* Set the dynamic target-system-dependant parameters (architecture,
+/* Set the dynamic target-system-dependent parameters (architecture,
    byte-order, ...) using information found in the BFD */
 
 extern void set_gdbarch_from_file (bfd *);
Index: gdbtypes.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.c,v
retrieving revision 1.13
diff -u -p -r1.13 gdbtypes.c
--- gdbtypes.c	2000/08/25 20:51:19	1.13
+++ gdbtypes.c	2000/09/01 23:20:57
@@ -82,7 +82,7 @@ struct extra
   {
     char str[128];
     int len;
-  };				/* maximum extention is 128! FIXME */
+  };				/* maximum extension is 128! FIXME */
 
 static void add_name (struct extra *, char *);
 static void add_mangled_type (struct extra *, struct type *);
Index: gdbtypes.h
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.h,v
retrieving revision 1.5
diff -u -p -r1.5 gdbtypes.h
--- gdbtypes.h	2000/05/28 01:12:27	1.5
+++ gdbtypes.h	2000/09/01 23:20:58
@@ -147,7 +147,7 @@ enum type_code
 
 /* No sign for this type.  In C++, "char", "signed char", and "unsigned
    char" are distinct types; so we need an extra flag to indicate the
-   absence ofa sign! */
+   absence of a sign! */
 
 #define TYPE_FLAG_NOSIGN	(1 << 1)
 
Index: infcmd.c
===================================================================
RCS file: /cvs/src/src/gdb/infcmd.c,v
retrieving revision 1.10
diff -u -p -r1.10 infcmd.c
--- infcmd.c	2000/08/01 14:48:00	1.10
+++ infcmd.c	2000/09/01 23:20:58
@@ -1067,7 +1067,7 @@ print_return_value (int structure_return
    only chance we have to complete this command is in
    fetch_inferior_event, which is called by the event loop as soon as it
    detects that the target has stopped. This function is called via the
-   cmd_continaution pointer. */
+   cmd_continuation pointer. */
 void
 finish_command_continuation (struct continuation_arg *arg)
 {
Index: infrun.c
===================================================================
RCS file: /cvs/src/src/gdb/infrun.c,v
retrieving revision 1.17
diff -u -p -r1.17 infrun.c
--- infrun.c	2000/07/30 01:48:25	1.17
+++ infrun.c	2000/09/01 23:21:02
@@ -1431,7 +1431,7 @@ handle_inferior_event (struct execution_
 	insert_breakpoints ();
 
 	/* We need to restart all the threads now,
-	 * unles we're running in scheduler-locked mode. 
+	 * unless we're running in scheduler-locked mode. 
 	 * FIXME: shouldn't we look at currently_stepping ()?
 	 */
 	if (scheduler_mode == schedlock_on)
Index: symfile.c
===================================================================
RCS file: /cvs/src/src/gdb/symfile.c,v
retrieving revision 1.17
diff -u -p -r1.17 symfile.c
--- symfile.c	2000/08/07 15:02:48	1.17
+++ symfile.c	2000/09/01 23:21:04
@@ -757,7 +757,7 @@ syms_from_objfile (struct objfile *objfi
   discard_cleanups (old_chain);
 
   /* Call this after reading in a new symbol table to give target
-     dependant code a crack at the new symbols.  For instance, this
+     dependent code a crack at the new symbols.  For instance, this
      could be used to update the values of target-specific symbols GDB
      needs to keep track of (such as _sigtramp, or whatever).  */
 
@@ -1742,7 +1742,7 @@ reread_symbols (void)
 	      reread_one = 1;
 
 	      /* Call this after reading in a new symbol table to give target
-	         dependant code a crack at the new symbols.  For instance, this
+	         dependent code a crack at the new symbols.  For instance, this
 	         could be used to update the values of target-specific symbols GDB
 	         needs to keep track of (such as _sigtramp, or whatever).  */
 
Index: symfile.h
===================================================================
RCS file: /cvs/src/src/gdb/symfile.h,v
retrieving revision 1.5
diff -u -p -r1.5 symfile.h
--- symfile.h	2000/06/04 00:41:09	1.5
+++ symfile.h	2000/09/01 23:21:04
@@ -64,7 +64,7 @@ struct psymbol_allocation_list
 #define MAX_SECTIONS 40
 struct section_addr_info 
 {
-  /* Sections whose names are file format dependant. */
+  /* Sections whose names are file format dependent. */
   struct other_sections
   {
     CORE_ADDR addr;
Index: target.h
===================================================================
RCS file: /cvs/src/src/gdb/target.h,v
retrieving revision 1.6
diff -u -p -r1.6 target.h
--- target.h	2000/06/04 00:41:09	1.6
+++ target.h	2000/09/01 23:21:05
@@ -1124,13 +1124,13 @@ extern void (*target_new_objfile_hook) (
 #define target_pid_to_exec_file(pid) \
      (current_target.to_pid_to_exec_file) (pid)
 
-/* Hook to call target-dependant code after reading in a new symbol table.  */
+/* Hook to call target-dependent code after reading in a new symbol table.  */
 
 #ifndef TARGET_SYMFILE_POSTREAD
 #define TARGET_SYMFILE_POSTREAD(OBJFILE)
 #endif
 
-/* Hook to call target dependant code just after inferior target process has
+/* Hook to call target dependent code just after inferior target process has
    started.  */
 
 #ifndef TARGET_CREATE_INFERIOR_HOOK
Index: tracepoint.h
===================================================================
RCS file: /cvs/src/src/gdb/tracepoint.h,v
retrieving revision 1.3
diff -u -p -r1.3 tracepoint.h
--- tracepoint.h	2000/06/04 00:41:09	1.3
+++ tracepoint.h	2000/09/01 23:21:05
@@ -107,7 +107,7 @@ enum actionline_type
   };
 
 
-/* The tracepont chain of all tracepoints */
+/* The tracepoint chain of all tracepoints */
 
 extern struct tracepoint *tracepoint_chain;
 


Regards,
David B. Anderson davea@sgi.com danderson@acm.org http://reality.sgi.com/davea/

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: arch-utils.h
===================================================================
RCS file: /cvs/src/src/gdb/arch-utils.h,v
retrieving revision 1.8
diff -u -p -r1.8 arch-utils.h
--- arch-utils.h	2000/08/02 11:05:50	1.8
+++ arch-utils.h	2000/09/01 23:20:48
@@ -76,13 +76,13 @@ extern int frame_num_args_unknown (struc
    targets. */
 
 /* DEPRECATED pre- multi-arch interface.  Explicitly set the dynamic
-   target-system-dependant parameters based on bfd_architecture and
+   target-system-dependent parameters based on bfd_architecture and
    machine.  This function is deprecated, use
    set_gdbarch_from_arch_machine(). */
 
 extern void set_architecture_from_arch_mach (enum bfd_architecture, unsigned long);
 
 /* DEPRECATED pre- multi-arch interface.  Notify the target dependant
    backend of a change to the selected architecture. A zero return
    status indicates that the target did not like the change. */
 
@@ -76,13 +76,13 @@ extern int frame_num_args_unknown (struc
 extern void set_architecture_from_arch_mach (enum bfd_architecture, unsigned long);
 
-/* DEPRECATED pre- multi-arch interface.  Notify the target dependant
+/* DEPRECATED pre- multi-arch interface.  Notify the target dependent
    backend of a change to the selected architecture. A zero return
    status indicates that the target did not like the change. */
Index: gdbarch.sh
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.sh,v
retrieving revision 1.41
diff -u -p -r1.41 gdbarch.sh
--- gdbarch.sh	2000/08/25 20:51:19	1.41
+++ gdbarch.sh	2000/09/01 23:20:56
@@ -593,7 +593,7 @@ done
 # function typedef's
 echo ""
 echo ""
-echo "/* The following are initialized by the target dependant code. */"
+echo "/* The following are initialized by the target dependent code. */"
 function_list | while do_read
 do
     if [ "${comment}" ]
@@ -699,7 +699,7 @@ extern struct gdbarch_tdep *gdbarch_tdep
 
    The mechanisms below ensures that there is only a loose connection
    between the set-architecture command and the various GDB
-   components.  Each component can independantly register their need
+   components.  Each component can independently register their need
    to maintain architecture specific data with gdbarch.
 
    Pragmatics:
@@ -709,7 +709,7 @@ extern struct gdbarch_tdep *gdbarch_tdep
 
    The more traditional mega-struct containing architecture specific
    data for all the various GDB components was also considered.  Since
-   GDB is built from a variable number of (fairly independant)
+   GDB is built from a variable number of (fairly independent)
    components it was determined that the global aproach was not
    applicable. */
 
@@ -869,7 +869,7 @@ extern void register_gdbarch_swap (void 
 
 
 
 /* The target-system-dependant byte order is dynamic */
 
 /* TARGET_BYTE_ORDER_SELECTABLE_P determines if the target endianness
    is selectable at runtime.  The user can use the \`\`set endian''
@@ -909,7 +909,7 @@ extern int target_byte_order_auto;
 
 
 
 /* The target-system-dependant BFD architecture is dynamic */
 
 extern int target_architecture_auto;
 #ifndef TARGET_ARCHITECTURE_AUTO
@@ -922,7 +922,7 @@ extern const struct bfd_arch_info *targe
 #endif
 
 
 /* The target-system-dependant disassembler is semi-dynamic */
 
 #include "dis-asm.h"		/* Get defs for disassemble_info */
 
@@ -963,7 +963,7 @@ extern disassemble_info tm_print_insn_in
 #endif
 
 
 /* Set the dynamic target-system-dependant parameters (architecture,
    byte-order, ...) using information found in the BFD */
 
 extern void set_gdbarch_from_file (bfd *);
@@ -1529,7 +1529,7 @@ gdbarch_data (struct gdbarch_data *data)
 
 
 
-/* Keep a registrary of swaped data required by GDB modules. */
+/* Keep a registrary of swapped data required by GDB modules. */
 
 struct gdbarch_swap
 {
@@ -869,7 +869,7 @@ extern void register_gdbarch_swap (void 
 
 
-/* The target-system-dependant byte order is dynamic */
+/* The target-system-dependent byte order is dynamic */
 
 /* TARGET_BYTE_ORDER_SELECTABLE_P determines if the target endianness
@@ -909,7 +909,7 @@ extern int target_byte_order_auto;
 
 
-/* The target-system-dependant BFD architecture is dynamic */
+/* The target-system-dependent BFD architecture is dynamic */
 
 extern int target_architecture_auto;
@@ -922,7 +922,7 @@ extern const struct bfd_arch_info *targe
 
 
-/* The target-system-dependant disassembler is semi-dynamic */
+/* The target-system-dependent disassembler is semi-dynamic */
 
 #include "dis-asm.h"		/* Get defs for disassemble_info */
@@ -963,7 +963,7 @@ extern disassemble_info tm_print_insn_in
 
 
-/* Set the dynamic target-system-dependant parameters (architecture,
+/* Set the dynamic target-system-dependent parameters (architecture,
    byte-order, ...) using information found in the BFD */
 